@@ -1,4 +1,4 @@
-# $Id: CBC.pm,v 1.4 2001/03/05 22:54:16 btrott Exp $
+# $Id: CBC.pm,v 1.5 2001/04/03 19:44:47 btrott Exp $
 
 # This code is based in part on the Systemics Crypt::CBC.
 # Parts copyright (C) 1995, 1996 Systemics Ltd (http://www.systemics.com/)
@@ -8,10 +8,10 @@ package Net::SSH::Perl::Cipher::CBC;
 use strict;
 
 sub new {
-    my($class, $ciph) = @_;
+    my($class, $ciph, $iv) = @_;
     bless {
         cipher => $ciph,
-        iv     => "\0" x $ciph->blocksize,
+        iv     => $iv || ("\0" x $ciph->blocksize),
     }, $class;
 }
 
