@@ -1,9 +1,9 @@
-# $Id: DSA.pm,v 1.22 2001/05/11 22:10:41 btrott Exp $
+# $Id: DSA.pm,v 1.23 2001/07/11 21:57:33 btrott Exp $
 
 package Net::SSH::Perl::Key::DSA;
 use strict;
 
-use Net::SSH::Perl::Buffer qw( SSH2 );
+use Net::SSH::Perl::Buffer;
 use Net::SSH::Perl::Constants qw( SSH_COMPAT_BUG_SIGBLOB );
 use Net::SSH::Perl::Util qw( :ssh2mp );
 
@@ -27,7 +27,7 @@ sub init {
     my($blob, $datafellows) = @_;
 
     if ($blob) {
-        my $b = Net::SSH::Perl::Buffer->new;
+        my $b = Net::SSH::Perl::Buffer->new( MP => 'SSH2' );
         $b->append($blob);
         my $ktype = $b->get_str;
         croak __PACKAGE__, "->init: cannot handle type '$ktype'"
@@ -97,7 +97,7 @@ sub sign {
         return $sigblob;
     }
     else {
-        my $b = Net::SSH::Perl::Buffer->new;
+        my $b = Net::SSH::Perl::Buffer->new( MP => 'SSH2' );
         $b->put_str($key->ssh_name);
         $b->put_str($sigblob);
         $b->bytes;
@@ -113,7 +113,7 @@ sub verify {
         $sigblob = $signature;
     }
     else {
-        my $b = Net::SSH::Perl::Buffer->new;
+        my $b = Net::SSH::Perl::Buffer->new( MP => 'SSH2' );
         $b->append($signature);
         my $ktype = $b->get_str;
         croak "Can't verify type ", $ktype unless $ktype eq $key->ssh_name;
@@ -140,7 +140,7 @@ sub equal {
 
 sub as_blob {
     my $key = shift;
-    my $b = Net::SSH::Perl::Buffer->new;
+    my $b = Net::SSH::Perl::Buffer->new( MP => 'SSH2' );
     $b->put_str($key->ssh_name);
     $b->put_mp_int($key->{dsa}->p);
     $b->put_mp_int($key->{dsa}->q);
